.. _installation:

Getting Started
===============

hpiPy can be installed using pip:

.. code-block:: bash

   pip install hpipy

Dependencies
------------

The hpiPy package requires the following dependencies:

* captum
* h3
* numpy
* pandas
* quantile-forest
* scikit-learn
* scipy
* statsmodels
* torch

.. toctree::
   :maxdepth: 1
   :caption: Installation
   :hidden:

   self
   developers
